aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java b/src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java
index 7849ea52a6..1396779f83 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/cpp/CppToolchainInfo.java
@@ -199,14 +199,16 @@ public final class CppToolchainInfo {
crosstoolInfo.getLdEmbedFlags(),
crosstoolInfo.getObjcopyEmbedFlags(),
toolchainLabel,
- toolchainLabel.getRelative(
+ toolchainLabel.getRelativeWithRemapping(
!crosstoolInfo.getStaticRuntimesFilegroup().isEmpty()
? crosstoolInfo.getStaticRuntimesFilegroup()
- : "static-runtime-libs-" + crosstoolInfo.getTargetCpu()),
- toolchainLabel.getRelative(
+ : "static-runtime-libs-" + crosstoolInfo.getTargetCpu(),
+ ImmutableMap.of()),
+ toolchainLabel.getRelativeWithRemapping(
!crosstoolInfo.getDynamicRuntimesFilegroup().isEmpty()
? crosstoolInfo.getDynamicRuntimesFilegroup()
- : "dynamic-runtime-libs-" + crosstoolInfo.getTargetCpu()),
+ : "dynamic-runtime-libs-" + crosstoolInfo.getTargetCpu(),
+ ImmutableMap.of()),
"_solib_" + crosstoolInfo.getTargetCpu(),
crosstoolInfo.getAbiVersion(),
crosstoolInfo.getTargetSystemName(),
@@ -224,8 +226,8 @@ public final class CppToolchainInfo {
crosstoolInfo.supportsGoldLinker(),
crosstoolInfo.needsPic());
} catch (LabelSyntaxException e) {
// All of the above label.getRelative() calls are valid labels, and the crosstool_top
// was already checked earlier in the process.
throw new AssertionError(e);
}
}
@@ -224,8 +226,8 @@ public final class CppToolchainInfo {
crosstoolInfo.needsPic());
} catch (LabelSyntaxException e) {
- // All of the above label.getRelative() calls are valid labels, and the crosstool_top
- // was already checked earlier in the process.
+ // All of the above label.getRelativeWithRemapping() calls are valid labels, and the
+ // crosstool_top was already checked earlier in the process.
throw new AssertionError(e);
}